from .bmkg import BMKG
from .earthquake import Earthquake
from .shakemap import Shakemap
from .weather_forecast import WeatherForecast

__all__ = [
    "BMKG",
    "Earthquake",
    "Shakemap",
    "WeatherForecast",
]
