"""
Module to store common enum classes used by bmkg.
"""
from .cardinal import Cardinal
from .province import Province
from .sexa import Sexa
from .type import Type
from .weather import Weather

__all__ = [
    "Cardinal",
    "Province",
    "Sexa",
    "Type",
    "Weather",
]
